import { API_URL } from '$env/static/private';

import { fail, redirect, type Actions } from '@sveltejs/kit';

import type { PageServerLoad } from './$types';

import { zod } from 'sveltekit-superforms/adapters';
import { superValidate } from 'sveltekit-superforms/server';
import { z } from 'zod';


export const load = (async ({ locals: { user } }) => {
	if (user) redirect(303, '/dashboard');

	const form = await superValidate(zod(schema));

	return {
		form
	};
}) satisfies PageServerLoad;

const schema = z.object({
	pseudo: z.string().trim(),
	passwd: z.string()
});

export const actions = {
	default: async ({ request, cookies }) => {
		const form = await superValidate(request, zod(schema));

		if (!form.valid) {
			return fail(400, { form });
		}

		const res = await fetch(`${API_URL}/login`, {
			method: 'POST',
			body: JSON.stringify({
				...form.data
			})
		});

		if (res.ok) {
			const token = res.headers.get('Authorization')?.split(' ')[1];

			if (!token) {

				form.errors.passwd = ["Une erreur est survenue, veuillez réessayer plus tard"];

				return fail(500, { form });
			}

			cookies.set('session', token, {
				path: '/'
			});

			return {
				form
			};
		}

		form.errors.passwd = ["Nom d'utilisateur ou mot de passe incorrect"];

		return fail(400, {
			form
		});
	}
} satisfies Actions;
